@@ -105,6 +105,7 @@ sub _options {
             { name => '_split_config',      text => "- split settings", section => 'split'  },
             { name => '_csv_char',          text => "- CSV settings-a", section => 'csv'    },
             { name => '_csv_options',       text => "- CSV settings-b", section => 'csv'    },
+            { name => '_empty_to_null',     text => "- Empty to NULL",  section => 'insert' },
             { name => '_file_encoding',     text => "- File encoding",  section => 'insert' },
             { name => 'history_dirs',       text => "- Dir history",    section => 'insert' },
             { name => '_file_filter',       text => "- File filter",    section => 'insert' },
@@ -356,6 +357,15 @@ sub set_options {
                 ];
                 $sf->__settings_menu_wrap( $section, $sub_menu, $prompt );
             }
+            elsif ( $opt eq '_empty_to_null' ) {
+                my $prompt = 'Enable "Empty to NULL" by default:';
+                my $sub_menu = [
+                    [ 'empty_to_null_plain',  "- Source type 'plain'",  [ $no, $yes ] ],
+                    [ 'empty_to_null_copy',   "- Source type 'copy'",   [ $no, $yes ] ],
+                    [ 'empty_to_null_file',   "- Source tpye 'file'",   [ $no, $yes ] ],
+                ];
+                $sf->__settings_menu_wrap( $section, $sub_menu, $prompt );
+            }
             elsif ( $opt eq '_grid' ) {
                 my $prompt = '"Grid"';
                 my $sub_menu = [
